Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/adxl34x_simpletest.py
    :caption: examples/adxl34x_simpletest.py
    :linenos:

Motion detection
----------------

Use the accelerometer to detect motion.

.. literalinclude:: ../examples/adxl34x_motion_detection_test.py
    :caption: examples/adxl34x_motion_detection_test.py
    :linenos:

Freefall detection
------------------

Use the accelerometer to detect when something is dropped.

.. literalinclude:: ../examples/adxl34x_freefall_detection_test.py
    :caption: examples/adxl34x_freefall_detection_test.py
    :linenos:

Tap detection
-------------

The accelerometer can also be configured to detect taps.

.. literalinclude:: ../examples/adxl34x_tap_detection_test.py
    :caption: examples/adxl34x_tap_detection_test.py
    :linenos:
